@@ -9,7 +9,7 @@
 #ifndef WLR_TYPES_WLR_VIRTUAL_KEYBOARD_V1_H
 #define WLR_TYPES_WLR_VIRTUAL_KEYBOARD_V1_H
 
-#include <wayland-server.h>
+#include <wayland-server-core.h>
 #include <wlr/interfaces/wlr_input_device.h>
 #include <wlr/interfaces/wlr_keyboard.h>
 
@@ -30,6 +30,7 @@ struct wlr_virtual_keyboard_v1 {
 	struct wl_resource *resource;
 	struct wlr_input_device input_device;
 	struct wlr_seat *seat;
+	bool has_keymap;
 
 	struct wl_list link;
 
